#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_FAST_HYPOT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_FAST_HYPOT_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/simd/fast_hypot.hpp>

#endif
